@@ -527,12 +527,12 @@ void showReadMe()
   char buf[4096*4];	//buffer to hold data
   int buf_len = 0;
   
-  if(!(README = fopen("/usr/share/doc/Prime/README", "r"))) 
+  if(!(README = fopen("/usr/share/doc/gnudos/prime/README", "r"))) 
   {
-   if(!(README = fopen("/usr/local/share/doc/Prime/README", "r"))) 
+   if(!(README = fopen("/usr/local/share/doc/gnudos/prime/README", "r"))) 
    {
     msgBox("Failed to open README file!.", OK, ERROR);
-    fprintf(log_file, "Failed to open /usr/share/doc/Prime/README file..\n");
+    fprintf(log_file, "Failed to open /usr/share/doc/gnudos/prime/README file..\n");
     scanDir(cwd);
     return;
    }
